==> magento-ece-tools-2002.0.16.zip: src/Config/Validator/Deploy/ElasticSearchUsage.php <==
<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
namespace Magento\MagentoCloud\Config\Validator\Deploy;

use Magento\MagentoCloud\Config\Environment;
use Magento\MagentoCloud\Config\Validator;
use Magento\MagentoCloud\Config\ValidatorInterface;
use Magento\MagentoCloud\Process\Deploy\InstallUpdate\ConfigUpdate\SearchEngine\Config as SearchEngineConfig;

/**
 * Validates that different search engine configured when elasticsearch service is installed.
 */
class ElasticSearchUsage implements ValidatorInterface
{
    /**
     * @var SearchEngineConfig
     */
    private $searchEngineConfig;

    /**
     * @var Validator\ResultFactory
     */
    private $resultFactory;

    /**
     * @var Environment
     */
    private $environment;

    /**
     * @param Environment $environment
     * @param SearchEngineConfig $searchEngineConfig
     * @param Validator\ResultFactory $resultFactory
     */
    public function __construct(
        Environment $environment,
        SearchEngineConfig $searchEngineConfig,
        Validator\ResultFactory $resultFactory
    ) {
        $this->searchEngineConfig = $searchEngineConfig;
        $this->resultFactory = $resultFactory;
        $this->environment = $environment;
    }

    /**
     * Returns success when elasticsearch service not exist.
     * Returns success when elasticsearch service exist and search engine configured as elasticsearch.
     * Otherwise returns error.
     *
     * @return Validator\ResultInterface
     */
    public function validate(): Validator\ResultInterface
    {
        $relationships = $this->environment->getRelationships();
        if (!isset($relationships['elasticsearch'])) {
            return $this->resultFactory->success();
        }

        $searchEngine = $this->searchEngineConfig->get()['engine'];
        if (strpos($searchEngine, 'elasticsearch') === 0) {
            return $this->resultFactory->success();
        }

        return $this->resultFactory->error(
            'Elasticsearch service is installed at infrastructure layer but is not used as a search engine.',
            'Consider removing elasticsearch service from infrastructure layer for optimized resource usage.'
        );
    }
}

==> magento-ece-tools-2002.0.20.zip: src/Config/Validator/Deploy/ElasticSearchUsage.php <==
<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
declare(strict_types=1);

namespace Magento\MagentoCloud\Config\Validator\Deploy;

use Magento\MagentoCloud\Config\Validator;
use Magento\MagentoCloud\Config\ValidatorInterface;
use Magento\MagentoCloud\Config\SearchEngine;

/**
 * Validates that different search engine configured when elasticsearch service is installed.
 */
class ElasticSearchUsage implements ValidatorInterface
{
    /**
     * @var SearchEngine
     */
    private $searchEngine;

    /**
     * @var Validator\ResultFactory
     */
    private $resultFactory;

    /**
     * @var SearchEngine\ElasticSearch
     */
    private $elasticSearch;

    /**
     * @param SearchEngine $searchEngine
     * @param Validator\ResultFactory $resultFactory
     * @param SearchEngine\ElasticSearch $elasticSearch
     */
    public function __construct(
        SearchEngine $searchEngine,
        Validator\ResultFactory $resultFactory,
        SearchEngine\ElasticSearch $elasticSearch
    ) {
        $this->searchEngine = $searchEngine;
        $this->resultFactory = $resultFactory;
        $this->elasticSearch = $elasticSearch;
    }

    /**
     * Returns success when elasticsearch service not exist.
     * Returns success when elasticsearch service exist and search engine
     * configured as elasticsearch or elasticsuite.
     * Otherwise returns error.
     *
     * @return Validator\ResultInterface
     */
    public function validate(): Validator\ResultInterface
    {
        if (!$this->elasticSearch->isInstalled()) {
            return $this->resultFactory->success();
        }

        if ($this->searchEngine->isESFamily()) {
            return $this->resultFactory->success();
        }

        return $this->resultFactory->error(
            'Elasticsearch service is installed at infrastructure layer but is not used as a search engine.',
            'Consider removing elasticsearch service from infrastructure layer for optimized resource usage.'
        );
    }
}
